@@ -24,7 +24,6 @@ import gobject
 from proxy import AccessibilityProxy
 
 import sys
-import traceback
 
 def _get_accessibility_bus_address ():
 
@@ -67,8 +66,22 @@ class _AccessibilityBus (_bus.BusConnection):
 	def __init__ (self, address, mainloop):
 		_bus.BusConnection.__init__(self, address, mainloop)
 		self._signal_queue = _queue.Queue ()
+                self.eventsFrozen = False
+                self.needEventDispatch = False
+
+        def freezeEvents(self):
+                self.eventsFrozen = True
+
+        def thawEvents(self):
+                self.eventsFrozen = False
+                if self.needEventDispatch:
+                	gobject.idle_add(self._event_dispatch)
+                        self.needEventDispatch = False
 
 	def _event_dispatch (self):
+                if self.eventsFrozen:
+                        self.needEventDispatch = True
+                        return
 		while not self._signal_queue.empty():
 			(func, args, kwargs) = self._signal_queue.get (False)
 			func (*args, **kwargs)
@@ -78,7 +91,10 @@ class _AccessibilityBus (_bus.BusConnection):
 		
 		def wrapper (*iargs, **ikwargs):
 			self._signal_queue.put ((func, iargs, ikwargs))
-                	gobject.idle_add(self._event_dispatch)
+                        if self.eventsFrozen:
+                	        self.needEventDispatch = True
+                        else:
+                	        gobject.idle_add(self._event_dispatch)
 
 		return _bus.BusConnection.add_signal_receiver (self, wrapper, *args, **kwargs)
 
@@ -97,7 +113,7 @@ class AsyncAccessibilityBus (_AccessibilityBus):
 
 	_shared_instance = None
 	
-	def __new__ (cls):
+	def __new__ (cls, registry):
 		if AsyncAccessibilityBus._shared_instance:
 			return AsyncAccessibilityBus._shared_instance
 		else:
@@ -110,11 +126,12 @@ class AsyncAccessibilityBus (_AccessibilityBus):
 			
 			return AsyncAccessibilityBus._shared_instance
 
-	def __init__ (self):
+	def __init__ (self, registry):
 		try:
 			_AccessibilityBus.__init__ (self, _get_accessibility_bus_address(), None)
 		except Exception:
 			_AccessibilityBus.__init__ (self, _bus.BusConnection.TYPE_SESSION, None)
+                self.registry = registry
 
 class SyncAccessibilityBus (_bus.BusConnection):
 	"""
@@ -123,7 +140,7 @@ class SyncAccessibilityBus (_bus.BusConnection):
 
 	_shared_instance = None
 	
-	def __new__ (cls):
+	def __new__ (cls, registry):
 		if SyncAccessibilityBus._shared_instance:
 			return SyncAccessibilityBus._shared_instance
 		else:
@@ -136,8 +153,9 @@ class SyncAccessibilityBus (_bus.BusConnection):
 			
 			return SyncAccessibilityBus._shared_instance
 
-	def __init__ (self):
+	def __init__ (self, registry):
 		try:
 			_bus.BusConnection.__init__ (self, _get_accessibility_bus_address(), None)
 		except Exception:
 			_bus.BusConnection.__init__ (self, _bus.BusConnection.TYPE_SESSION, None)
+                self.registry = registry
